@@ -28,11 +28,10 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 
 #include <libgnome/gnome-macros.h>
-#include <libgnome/gnome-i18n.h>
-#include "gnome-desktop-i18n.h"
 
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomeui/gnome-icon-entry.h>
@@ -125,6 +124,11 @@ gnome_ditem_edit_class_init (GnomeDItemEditClass *klass)
         object_class = (GtkObjectClass*) klass;
         gobject_class = (GObjectClass*) klass;
 
+        bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+#    ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#    endif
+
         ditem_edit_signals[CHANGED] =
                 g_signal_new ("changed",
                                 G_TYPE_FROM_CLASS (object_class),
@@ -1027,18 +1031,14 @@ gnome_ditem_edit_sync_display (GnomeDItemEdit *dee)
 static const char *
 get_language (void)
 {
-	/* there is some include header problem and we can't include the
-	   gnome i18n header or some such */
-	extern const GList *gnome_i18n_get_language_list (const char *category);
+	const char * const *languages;
+        int                 i;
 
-	const GList *list;
-	const GList *l;
+        languages = g_get_language_names ();
 
-	list = gnome_i18n_get_language_list ("LC_MESSAGES");
-
-	for (l = list; l; l = l->next)
-		if (!strchr (l->data, '.'))
-			return (char *) l->data;
+	for (i = 0; languages[i] != NULL; i++)
+		if (!strchr (languages[i], '.'))
+			return languages[i];
 
 	return NULL;
 }
